@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: blaze-builder
-version: 0.2.1.4
-id: blaze-builder-0.2.1.4-ad5ca2b353a9c2419d1c843e4c41a350
+version: 0.3.1.1
+id: blaze-builder-0.3.1.1-ac49b512143342e2370aead8ef93c70b
 
 license: BSD3
 copyright: 2010 Simon Meier
@@ -10,6 +10,7 @@ maintainer: Simon Meier <iridcode@gmail.com>
 stability: Experimental
 homepage: http://github.com/meiersi/blaze-builder
 package-url:
+synopsis: Efficient buffered output.
 description: This library provides an abstraction of buffered output of
              byte streams and several convenience functions to exploit
              it. For example, it allows to efficiently serialize
@@ -33,21 +34,22 @@ exposed-modules: Blaze.ByteString.Builder
                  Blaze.ByteString.Builder.Internal.Types
                  Blaze.ByteString.Builder.Internal.Buffer
 hidden-modules: Blaze.ByteString.Builder.Internal.UncheckedShifts
-import-dirs: /usr/local/lib/ghc/blaze-builder-0.2.1.4
-library-dirs: /usr/local/lib/ghc/blaze-builder-0.2.1.4
-hs-libraries: HSblaze-builder-0.2.1.4
+trusted: False
+import-dirs: /usr/local/lib/ghc/blaze-builder-0.3.1.1
+library-dirs: /usr/local/lib/ghc/blaze-builder-0.3.1.1
+hs-libraries: HSblaze-builder-0.3.1.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-912d55d387093f740e3bcd2ffbf1dd83
-         bytestring-0.9.1.10-e7cebdd905566e960c42140389871ec1
-         text-0.11.0.6-ace87dcbd28176f4bf784c8b8e080ab9
+depends: base-4.6.0.1-185478ee9bcc4ae00bc1dbe06bac6937
+         bytestring-0.10.0.2-fdb789c5db2e1ca48eb014403eee81b4
+         text-0.11.3.1-3fa3b4cb4ca4c0f49eeebe965c439ff9
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-blaze-builder-0.2.1.4/html/blaze-builder.haddock
-haddock-html: /usr/local/share/doc/hs-blaze-builder-0.2.1.4/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-blaze-builder-0.3.1.1/html/blaze-builder.haddock
+haddock-html: /usr/local/share/doc/hs-blaze-builder-0.3.1.1/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
